@@ -17,20 +17,29 @@ class Models(str, Enum):
         >>> model.forecast.get_latest()
     """
 
+    # With Grid Access
     EPT1_5 = "ept1_5"
     EPT1_5_EARLY = "ept1_5_early"
     EPT2 = "ept2"
-    EPT2_EARLY = "ept2_early"
-    EPT2_RR = "ept2_rr"
-    ECMWF_IFS_SINGLE = "ecmwf_ifs025_single"
-    ECMWF_IFS_ENSEMBLE = "ecmwf_ifs025_ensemble"
-    ECMWF_AIFS_SINGLE = "ecmwf_aifs025_single"
-    ECMWF_AIFS_ENSEMBLE = "ecmwf_aifs025_ensemble"
-    METEOFRANCE_AROME_FRANCE_HD = "meteofrance_arome_france_hd"
-    GFS_GLOBAL_SINGLE = "gfs_global_single"
-    GFS_GLOBAL_ENSEMBLE = "gfs_global_ensemble"
-    ICON_EU = "icon_eu"
-    GFS_GRAPHCAST = "gfs_graphcast025"
-    AURORA = "aurora"
-    AIFS = "aifs"
     EPT2_E = "ept2_e"
+    EPT2_EARLY = "ept2_early"
+    EPT2_HRRR = "ept2_hrrr"
+    EPT2_RR = "ept2_rr"
+    AIFS = "aifs"
+    AURORA = "aurora"
+    ECMWF_IFS_SINGLE = "ecmwf_ifs_single"
+
+    # Without Grid Access
+    ECMWF_AIFS_ENSEMBLE = "ecmwf_aifs025_ensemble"
+    ECMWF_AIFS_SINGLE = "ecmwf_aifs025_single"
+    ECMWF_IFS_ENSEMBLE = "ecmwf_ifs025_ensemble"
+    GFS_GLOBAL_ENSEMBLE = "gfs_global_ensemble"
+    GFS_GLOBAL_SINGLE = "gfs_global_single"
+    GFS_GRAPHCAST = "gfs_graphcast025"
+    ICON_D2 = "icon_d2"
+    ICON_EU = "icon_eu"
+    KNMI_HARMONIE_AROME_EUROPE = "knmi_harmonie_arome_europe"
+    KNMI_HARMONIE_AROME_NETHERLANDS = "knmi_harmonie_arome_netherlands"
+    METEOFRANCE_AROME_FRANCE_HD = "meteofrance_arome_france_hd"
+    UKMO_GLOBAL_DETERMINISTIC_10KM = "ukmo_global_deterministic_10km"
+    UKMO_UK_DETERMINISTIC_2KM = "ukmo_uk_deterministic_2km"
